==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/floating_toolbar/fragment_configuration/field_types/CheckboxField.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/floating_toolbar/fragment_configuration/field_types/CheckboxField.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './CheckboxFieldDelegateTemplate.soy', './CheckboxField.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.CheckboxField = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("./CheckboxFieldDelegateTemplate.soy");

  var _CheckboxField = _interopRequireDefault(require("./CheckboxField.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * CheckboxField
   */
  var CheckboxField =
  /*#__PURE__*/
  function (_Component) {
    _inherits(CheckboxField, _Component);

    function CheckboxField() {
      _classCallCheck(this, CheckboxField);

      return _possibleConstructorReturn(this, _getPrototypeOf(CheckboxField).apply(this, arguments));
    }

    _createClass(CheckboxField, [{
      key: "_handleCheckboxValueChanged",

      /**
       * Handle Checkbox Value Change
       * @param {Event} event
       * @private
       * @review
       */
      value: function _handleCheckboxValueChanged(event) {
        var targetElement = event.delegateTarget;
        this.emit('fieldValueChanged', {
          name: this.field.name,
          value: targetElement.checked
        });
      }
    }]);

    return CheckboxField;
  }(_metalComponent["default"]);

  exports.CheckboxField = CheckboxField;
  CheckboxField.STATE = {
    /**
     * The configuration field
     * @review
     * @type {object}
     */
    field: _metalState.Config.shapeOf({
      dataType: _metalState.Config.string(),
      defaultValue: _metalState.Config.bool(),
      description: _metalState.Config.string(),
      label: _metalState.Config.string(),
      name: _metalState.Config.string(),
      type: _metalState.Config.string(),
      typeOptions: _metalState.Config.object()
    })
  };

  _metalSoy["default"].register(CheckboxField, _CheckboxField["default"]);

  var _default = CheckboxField;
  exports["default"] = _default;
  //# sourceMappingURL=CheckboxField.es.js.map
});
//# sourceMappingURL=CheckboxField.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.126.jar: META-INF/resources/js/components/floating_toolbar/fragment_configuration/field_types/CheckboxField.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.126/js/components/floating_toolbar/fragment_configuration/field_types/CheckboxField.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './CheckboxFieldDelegateTemplate.soy', './CheckboxField.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.CheckboxField = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("./CheckboxFieldDelegateTemplate.soy");

  var _CheckboxField = _interopRequireDefault(require("./CheckboxField.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * CheckboxField
   */
  var CheckboxField = /*#__PURE__*/function (_Component) {
    _inherits(CheckboxField, _Component);

    function CheckboxField() {
      _classCallCheck(this, CheckboxField);

      return _possibleConstructorReturn(this, _getPrototypeOf(CheckboxField).apply(this, arguments));
    }

    _createClass(CheckboxField, [{
      key: "_handleCheckboxValueChanged",

      /**
       * Handle Checkbox Value Change
       * @param {Event} event
       * @private
       * @review
       */
      value: function _handleCheckboxValueChanged(event) {
        var targetElement = event.delegateTarget;
        this.emit('fieldValueChanged', {
          name: this.field.name,
          value: targetElement.checked
        });
      }
    }]);

    return CheckboxField;
  }(_metalComponent["default"]);

  exports.CheckboxField = CheckboxField;
  CheckboxField.STATE = {
    /**
     * The configuration field
     * @review
     * @type {object}
     */
    field: _metalState.Config.shapeOf({
      dataType: _metalState.Config.string(),
      defaultValue: _metalState.Config.bool(),
      description: _metalState.Config.string(),
      label: _metalState.Config.string(),
      name: _metalState.Config.string(),
      type: _metalState.Config.string(),
      typeOptions: _metalState.Config.object()
    })
  };

  _metalSoy["default"].register(CheckboxField, _CheckboxField["default"]);

  var _default = CheckboxField;
  exports["default"] = _default;
  //# sourceMappingURL=CheckboxField.es.js.map
});
//# sourceMappingURL=CheckboxField.es.js.map
